@@ -1,7 +1,6 @@
-package Sub::Name;
-# git description: v0.10-TRIAL-4-gf093e04
-$Sub::Name::VERSION = '0.11'; # TRIAL
-# ABSTRACT: (re)name a sub
+package Sub::Name; # git description: v0.15-19-gb800ade
+# ABSTRACT: (Re)name a sub
+# KEYWORDS: subroutine function utility name rename symbol
 
 #pod =pod
 #pod
@@ -34,17 +33,14 @@ $Sub::Name::VERSION = '0.11'; # TRIAL
 #pod
 #pod =head1 SEE ALSO
 #pod
-#pod =over 4
-#pod
-#pod =item *
-#pod L<Sub::Identify> - for getting information about subs
-#pod
-#pod =back
-#pod
-#pod =head1 COPYRIGHT AND LICENSE
+#pod =for :list
+#pod * L<Sub::Identify> - for getting information about subs
+#pod * L<Sub::Util> - set_subname is another implementation of C<subname>
 #pod
 #pod =for stopwords cPanel
 #pod
+#pod =head1 COPYRIGHT AND LICENSE
+#pod
 #pod This software is copyright (c) 2004, 2008 by Matthijs van Duin, all rights reserved;
 #pod copyright (c) 2014 cPanel Inc., all rights reserved.
 #pod
@@ -58,6 +54,8 @@ use 5.006;
 use strict;
 use warnings;
 
+our $VERSION = '0.16'; # TRIAL
+
 use Exporter 5.57 'import';
 
 our @EXPORT = qw(subname);
@@ -66,9 +64,7 @@ our @EXPORT_OK = @EXPORT;
 use XSLoader;
 XSLoader::load(
     __PACKAGE__,
-    exists $Sub::Name::{VERSION}
-        ? ${ $Sub::Name::{VERSION} }
-        : (),
+    $VERSION,
 );
 
 1;
@@ -81,11 +77,11 @@ __END__
 
 =head1 NAME
 
-Sub::Name - (re)name a sub
+Sub::Name - (Re)name a sub
 
 =head1 VERSION
 
-version 0.11
+version 0.16
 
 =head1 SYNOPSIS
 
@@ -119,17 +115,24 @@ can be very useful for debugging.
 =over 4
 
 =item *
+
 L<Sub::Identify> - for getting information about subs
 
+=item *
+
+L<Sub::Util> - set_subname is another implementation of C<subname>
+
 =back
 
 =for stopwords cPanel
 
-This software is copyright (c) 2004, 2008 by Matthijs van Duin, all rights reserved;
-copyright (c) 2014 cPanel Inc., all rights reserved.
+=head1 SUPPORT
 
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Sub-Name>
+(or L<bug-Sub-Name@rt.cpan.org|mailto:bug-Sub-Name@rt.cpan.org>).
+
+There is also an irc channel available for users of this distribution, at
+L<C<#toolchain> on C<irc.perl.org>|irc://irc.perl.org/#toolchain>.
 
 =head1 AUTHOR
 
@@ -137,7 +140,7 @@ Matthijs van Duin <xmath@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Karen Etheridge Florian Ragwitz Matthijs van Duin Reini Urban Dagfinn Ilmari Mannsåker gfx J.R. Mash
+=for stopwords Karen Etheridge Florian Ragwitz Leon Timmermans Matthijs van Duin Reini Urban gfx Dagfinn Ilmari Mannsåker Aristotle Pagaltzis J.R. Mash
 
 =over 4
 
@@ -151,6 +154,10 @@ Florian Ragwitz <rafl@debian.org>
 
 =item *
 
+Leon Timmermans <fawaka@gmail.com>
+
+=item *
+
 Matthijs van Duin <xmath-no-spam@nospam.cpan.org>
 
 =item *
@@ -159,11 +166,15 @@ Reini Urban <rurban@cpanel.net>
 
 =item *
 
+gfx <gfuji@cpan.org>
+
+=item *
+
 Dagfinn Ilmari Mannsåker <ilmari@ilmari.org>
 
 =item *
 
-gfx <gfuji@cpan.org>
+Aristotle Pagaltzis <pagaltzis@gmx.de>
 
 =item *
 
@@ -173,4 +184,10 @@ J.R. Mash <jmash.code@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
+This software is copyright (c) 2004, 2008 by Matthijs van Duin, all rights reserved;
+copyright (c) 2014 cPanel Inc., all rights reserved.
+
+This program is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
+
 =cut
